Learn R Programming

marinespeed (version 0.1.0)

list_species: List species

Description

list_species returns a dataframe with all the species names and their WoRMS identifier (aphia_id).

Usage

list_species()

Arguments

Details

If the file with the list of species is not present on the hard disk then it is downloaded and stored in the data directory. The data directory can be set with options(marinespeed_datadir = "."). By default data is downloaded to tempdir().

See Also

lapply_kfold_species, lapply_species, get_fold_data, get_occurrences, species_info

Examples

Run this code
species <- list_species()
head(species)

Run the code above in your browser using DataLab