Learn R Programming

marinespeed (version 0.1.0)

species_info: Species information

Description

species_info returns a dataframe with species information.

Usage

species_info()

Arguments

Details

Information about the taxonomy from the World Register of Marine Species (WoRMS), information on the covered latitudinal zones and the level of sample selection bias.

See Also

list_species

Examples

Run this code
info <- species_info()
unique(info$kingdom)
colnames(info)

Run the code above in your browser using DataLab