list_species returns a dataframe with all the species names and their
WoRMS identifier (aphia_id).
Usage
list_species()
Arguments
Details
If the file with the list of species is not present on the hard disk
then it is downloaded and stored in the data directory. The data directory
can be set with options(marinespeed_datadir = "."). By default data
is downloaded to tempdir().